@@ -600,12 +600,16 @@ class Win32CPUInfo(CPUInfoBase):
     # mean?
 
     def __init__(self):
+        try:
+            import winreg
+        except ImportError:  # Python 3
+            import winreg as _winreg
+
         if self.info is not None:
             return
         info = []
         try:
             #XXX: Bad style to use so long `try:...except:...`. Fix it!
-            import winreg
 
             prgx = re.compile(r"family\s+(?P<FML>\d+)\s+model\s+(?P<MDL>\d+)" \
                               "\s+stepping\s+(?P<STP>\d+)", re.IGNORECASE)
@@ -636,8 +640,7 @@ class Win32CPUInfo(CPUInfoBase):
                                     info[-1]["Model"] = int(srch.group("MDL"))
                                     info[-1]["Stepping"] = int(srch.group("STP"))
         except:
-            print()
-            sys.exc_info()[1], '(ignoring)'
+            print((sys.exc_info()[1], '(ignoring)'))
         self.__class__.info = info
 
     def _not_impl(self):
@@ -796,16 +799,13 @@ if __name__ == "__main__":
     cpu.is_Intel()
     cpu.is_Alpha()
 
-    print()
-    'CPU information:',
+    info = []
     for name in dir(cpuinfo):
         if name[0] == '_' and name[1] != '_':
             r = getattr(cpu, name[1:])()
             if r:
                 if r != 1:
-                    print()
-                    '%s=%s' % (name[1:], r),
+                    info.append('%s=%s' % (name[1:], r))
                 else:
-                    print()
-                    name[1:],
-    print()
+                    info.append(name[1:])
+    print(('CPU information: ' + ' '.join(info)))
